# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-04-09 13:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('location', '0004_auto_20180409_1319'),
    ]

    operations = [
        migrations.AlterField(
            model_name='city',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
        migrations.AlterField(
            model_name='citytranslation',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
        migrations.AlterField(
            model_name='country',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
        migrations.AlterField(
            model_name='countrytranslations',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
        migrations.AlterField(
            model_name='state',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
        migrations.AlterField(
            model_name='statetranslation',
            name='geocode',
            field=models.IntegerField(blank=True, default=0, editable=False, null=True, unique=True, verbose_name='Geocode'),
        ),
    ]
