# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-04-09 13:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('location', '0005_auto_20180409_1322'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='citytranslation',
            unique_together=set([('lang', 'city')]),
        ),
        migrations.AlterUniqueTogether(
            name='countrytranslations',
            unique_together=set([('lang', 'country')]),
        ),
        migrations.AlterUniqueTogether(
            name='statetranslation',
            unique_together=set([('lang', 'state')]),
        ),
    ]
